from apscheduler.schedulers.background import BackgroundScheduler
from config import config
from flask import Flask
from flask_login import LoginManager
from flask_mail import Mail
from flask_sqlalchemy import SQLAlchemy


db = SQLAlchemy()

login_manager = LoginManager()
login_manager.login_view = 'auth.login'

mail = Mail()

background_scheduler = BackgroundScheduler()


def create_app(config_name):
    app = Flask(__name__)
    app.config.from_object(config[config_name])
    config[config_name].init_app(app)

    db.init_app(app)
    login_manager.init_app(app)
    mail.init_app(app)

    from .auth import auth as auth_blueprint
    app.register_blueprint(auth_blueprint, url_prefix='/auth')

    from .main import main as main_blueprint
    app.register_blueprint(main_blueprint)

    from .scheduler import scheduler as scheduler_blueprint
    app.register_blueprint(scheduler_blueprint, url_prefix='/scheduler')

    background_scheduler.start()

    return app
